macro_rules! run_test {
($results:expr, $name:expr, $body:expr) => { ... };
}Expand description
Helper macro for running a test and capturing results.
macro_rules! run_test {
($results:expr, $name:expr, $body:expr) => { ... };
}Helper macro for running a test and capturing results.