prop_dedup_determinism

Function prop_dedup_determinism 

pub fn prop_dedup_determinism(
    ctx: &TestContext,
    keys: Vec<u32>,
    vals: Vec<u32>,
) -> Result<(), String>
Property: Dedup produces the same output for the same input.

Running dedup multiple times on identical input should produce identical output. The set of unique keys should match, and the number of rows should be correct.