pub fn prop_join_correctness(
ctx: &TestContext,
left_keys: Vec<u32>,
left_vals: Vec<u32>,
right_keys: Vec<u32>,
right_vals: Vec<u32>,
) -> Result<(), String>Expand description
Property: Hash join result equals the set of all matching pairs.
For each (key, lval) in left and (key, rval) in right where keys match, the result should contain exactly one (key, lval, rval) tuple.